'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _immutable = require('immutable');

var _delete = require('../delete');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nestedMaps = (0, _immutable.fromJS)({
  a: {
    b: "B"
  },
  f: "F"
});

var childLists = (0, _immutable.fromJS)({
  name: "root",
  children: [{
    name: "child 1",
    children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
  }]
});

(0, _tape2.default)('deepDelete', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)(nestedMaps.update((0, _delete.deepDelete)(['a', 'b'])), (0, _immutable.fromJS)({
    a: {},
    f: "F"
  })), 'using no childPath works like deleteIn');

  test.ok((0, _immutable.is)(childLists.update((0, _delete.deepDelete)([0, 0], ['children'])), (0, _immutable.fromJS)({
    name: "root",
    children: [{
      name: "child 1",
      children: [{ name: "grandchild 2" }]
    }]
  })), 'using childPath works correctly');
});

(0, _tape2.default)('deepDeleteChildren', function (test) {
  test.plan(4);

  test.ok((0, _immutable.is)(nestedMaps.update((0, _delete.deepDeleteChildren)(['a'])), (0, _immutable.fromJS)({
    a: {},
    f: "F"
  })), 'using no childPath clears children');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _delete.deepDeleteChildren)(['f'])), nestedMaps), 'using no childPath on a childless node does nothing');

  test.ok((0, _immutable.is)(childLists.update((0, _delete.deepDeleteChildren)([0], ['children'])), (0, _immutable.fromJS)({
    name: "root",
    children: [{
      name: "child 1",
      children: []
    }]
  })), 'using childPath works correctly');

  test.ok((0, _immutable.is)(childLists.update((0, _delete.deepDeleteChildren)([0, 1], ['children'])), (0, _immutable.fromJS)({
    name: "root",
    children: [{
      name: "child 1",
      children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
    }]
  })), 'using childPath on a childless node does nothing');
});