'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _immutable = require('immutable');

var _filter = require('../filter');

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nestedMaps = (0, _immutable.fromJS)({
  a: {
    b: "B",
    c: "C",
    d: "DD",
    e: {
      e: "E",
      f: "FF",
      g: "G"
    }
  },
  h: "H"
});

var childLists = (0, _immutable.fromJS)({
  name: "root",
  cool: true,
  children: [{
    name: "child 1",
    cool: true,
    children: [{ name: "grandchild 1", cool: true }, { name: "grandchild 2" }]
  }, {
    name: "child 2",
    children: [{ name: "grandchild 3", cool: true }, { name: "grandchild 4" }]
  }, { name: "child 3", cool: true }]
});

(0, _tape2.default)('deepFilter', function (test) {
  test.plan(2);
  test.ok((0, _immutable.is)(childLists.update((0, _filter.deepFilter)(function (item) {
    return item.get('cool');
  }, ['children'])), (0, _immutable.fromJS)({
    name: "root",
    cool: true,
    children: [{
      name: "child 1",
      cool: true,
      children: [{ name: "grandchild 1", cool: true }]
    }, { name: "child 3", cool: true }]
  })), 'deepFilter filters using a childPath');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _filter.deepFilter)(function (item) {
    // remove items that are strings and that are more than 1 character long
    return !(typeof item == "string" && item.length > 1);
  })), (0, _immutable.fromJS)({
    a: {
      b: "B",
      c: "C",
      e: {
        e: "E",
        g: "G"
      }
    },
    h: "H"
  })), 'deepFilter filters without using a childPath (kind of pointless)');

  console.log(nestedMaps);
});