'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _immutable = require('immutable');

var _get = require('../get');

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nestedMaps = (0, _immutable.fromJS)({
  a: {
    b: "B",
    c: "C",
    d: {
      e: "E"
    }
  },
  f: "F"
});

var nestedLists = (0, _immutable.fromJS)([["A", "B", "C"], ["D", ["E", "F"]], "G"]);

var childLists = (0, _immutable.fromJS)({
  name: "root",
  children: [{
    name: "child 1",
    children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
  }, {
    name: "child 2",
    children: []
  }, { name: "child 3" }]
});

(0, _tape2.default)('deepGet', function (test) {
  test.plan(5);

  test.ok((0, _immutable.is)(nestedMaps.update((0, _get.deepGet)()), nestedMaps), 'no params returns clone of original tree');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _get.deepGet)(['a', 'b'])), "B"), 'using no childPath works like getIn');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _get.deepGet)(['a', 'b', 'c', 'd'], null, "not set")), "not set"), 'not set value is returned if node at keys does not exist');

  test.ok((0, _immutable.is)(childLists.update((0, _get.deepGet)(null, ['children'])).get('name'), "root"), 'no keys with childPath returns root node');

  test.ok((0, _immutable.is)(childLists.update((0, _get.deepGet)([0, 1], ['children'])), (0, _immutable.fromJS)({ name: "grandchild 2" })), 'using childPath works correctly');
});

(0, _tape2.default)('deepGetChildren', function (test) {
  test.plan(5);

  test.ok((0, _immutable.is)(nestedMaps.update((0, _get.deepGetChildren)()), nestedMaps), 'no params returns clone of original tree');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _get.deepGetChildren)(['a', 'b'])), "B"), 'using no childPath works like getIn / deepget');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _get.deepGetChildren)(['a', 'b', 'c'], null, "not set")), "not set"), 'not set value is returned if no children at node');

  test.ok((0, _immutable.is)(childLists.update((0, _get.deepGetChildren)(null, ['children'])), childLists.get('children')), 'no keys with childPath returns root node children');

  test.ok((0, _immutable.is)(childLists.update((0, _get.deepGetChildren)([0], ['children'])), childLists.getIn(['children', 0, 'children'])), 'using childPath works correctly');
});