'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _immutable = require('immutable');

var _pick = require('../pick');

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nestedMaps = (0, _immutable.fromJS)({
  a: {
    b: "B",
    c: "C",
    d: {
      e: "E"
    }
  },
  f: "F"
});

var childLists = (0, _immutable.fromJS)({
  name: "root",
  children: [{
    name: "child 1",
    children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
  }, {
    name: "child 2",
    children: []
  }, { name: "child 3" }]
});

(0, _tape2.default)('deepPick', function (test) {
  test.plan(4);

  test.ok((0, _immutable.is)(childLists.update((0, _pick.deepPick)([0, 1], ['children'])), (0, _immutable.fromJS)({
    name: "root",
    children: [{
      name: "child 1",
      children: [{ name: "grandchild 2" }]
    }]
  })), 'deepPick picks out only values in a nodePath using a childPath');

  test.ok((0, _immutable.is)(childLists.update((0, _pick.deepPick)([0], ['children'])), (0, _immutable.fromJS)({
    name: "root",
    children: [{
      name: "child 1",
      children: []
    }]
  })), 'deepPick picks out only values in a nodePath using a childPath, without children of the last item in the nodePath');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _pick.deepPick)(['a', 'd', 'e'])), (0, _immutable.fromJS)({
    a: {
      d: {
        e: "E"
      }
    }
  })), 'deepPick picks out only values in a nodePath without using a childPath');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _pick.deepPick)(['a', 'd'])), (0, _immutable.fromJS)({
    a: {
      d: {}
    }
  })), 'deepPick picks out only values in a nodePath without using a childPath, without children of the last item in the nodePath');
});