'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _immutable = require('immutable');

var _reduce = require('../reduce');

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nestedMaps = (0, _immutable.fromJS)({
  a: {
    b: "B",
    c: "C",
    d: {
      e: "E"
    }
  },
  f: "F"
});

var childLists = (0, _immutable.fromJS)({
  name: "root",
  children: [{
    name: "child 1",
    children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
  }, {
    name: "child 2",
    children: []
  }, { name: "child 3" }]
});

(0, _tape2.default)('deepReduce', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)(childLists.update((0, _reduce.deepReduce)(function (reduction, item) {
    return reduction.push(item.get('name'));
  }, (0, _immutable.List)(), ['children'])), (0, _immutable.fromJS)(["grandchild 1", "grandchild 2", "child 1", "child 2", "child 3", "root"])), 'deepReduce iterates through every node using a childPath, from the outside in');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _reduce.deepReduce)(function (reduction, item) {
    // normally deepReduce on trees that don't require childPaths is a bit pointless
    // because you'll almost certainly have to deal with leaves and parents differently
    var a = (0, _utils.isLeaf)(item) ? item : "...";
    return reduction.push(a);
  }, (0, _immutable.List)())), (0, _immutable.fromJS)(["B", "C", "E", "...", "...", "F", "..."])), 'deepReduce iterates through every node without using a childPath (kind of pointless)');
});

(0, _tape2.default)('deepReduceLeaves', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)(childLists.update((0, _reduce.deepReduceLeaves)(function (reduction, item) {
    return reduction.push(item.get('name'));
  }, (0, _immutable.List)(), ['children'])), (0, _immutable.fromJS)(["grandchild 1", "grandchild 2", "child 2", "child 3"])), 'deepReduceLeaves iterates through every leaf node using a childPath, from the outside in');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _reduce.deepReduceLeaves)(function (reduction, item) {
    return reduction.push(item);
  }, (0, _immutable.List)())), (0, _immutable.fromJS)(["B", "C", "E", "F"])), 'deepReduceLeaves iterates through every leaf node without using a childPath');
});

(0, _tape2.default)('deepReduceParents', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)(childLists.update((0, _reduce.deepReduceParents)(function (reduction, item) {
    return reduction.push(item.get('name'));
  }, (0, _immutable.List)(), ['children'])), (0, _immutable.fromJS)(["child 1", "root"])), 'deepReduceParents iterates through every parent node using a childPath, from the outside in');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _reduce.deepReduceParents)(function (reduction, item) {
    return reduction.push(item.size);
  }, (0, _immutable.List)())), (0, _immutable.fromJS)([1, 3, 2])), 'deepReduceParents iterates through every parent node without using a childPath');
});

(0, _tape2.default)('deepReduceOutwards', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)(childLists.update((0, _reduce.deepReduceOutwards)(function (reduction, item) {
    return reduction.push(item.get('name'));
  }, (0, _immutable.List)(), ['children'])), (0, _immutable.fromJS)(["root", "child 1", "grandchild 1", "grandchild 2", "child 2", "child 3"])), 'deepReduceOutwards iterates through every node using a childPath, from the inside out');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _reduce.deepReduceOutwards)(function (reduction, item) {
    // normally deepReduceOutwards on trees that don't require childPaths is a bit pointless
    // because you'll almost certainly have to deal with leaves and parents differently
    var a = (0, _utils.isLeaf)(item) ? item : "...";
    return reduction.push(a);
  }, (0, _immutable.List)())), (0, _immutable.fromJS)(["...", "...", "B", "C", "...", "E", "F"])), 'deepReduceOutwards iterates through every node without using a childPath, from the inside out');
});

(0, _tape2.default)('deepReduceLeavesOutwards', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)(childLists.update((0, _reduce.deepReduceLeavesOutwards)(function (reduction, item) {
    return reduction.push(item.get('name'));
  }, (0, _immutable.List)(), ['children'])), (0, _immutable.fromJS)(["grandchild 1", "grandchild 2", "child 2", "child 3"])), 'deepReduceLeavesOutwards iterates through every leaf node using a childPath, from the inside out');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _reduce.deepReduceLeavesOutwards)(function (reduction, item) {
    return reduction.push(item);
  }, (0, _immutable.List)())), (0, _immutable.fromJS)(["B", "C", "E", "F"])), 'deepReduceLeavesOutwards iterates through every leaf node without using a childPath, from the inside out');
});

(0, _tape2.default)('deepReduceParentsOutwards', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)(childLists.update((0, _reduce.deepReduceParentsOutwards)(function (reduction, item) {
    return reduction.push(item.get('name'));
  }, (0, _immutable.List)(), ['children'])), (0, _immutable.fromJS)(["root", "child 1"])), 'deepReduceParentsOutwards iterates through every parent node using a childPath, from the inside out');

  test.ok((0, _immutable.is)(nestedMaps.update((0, _reduce.deepReduceParentsOutwards)(function (reduction, item) {
    return reduction.push(item.size);
  }, (0, _immutable.List)())), (0, _immutable.fromJS)([2, 3, 1])), 'deepReduceParentsOutwards iterates through every parent node without using a childPath, from the inside out');
});