'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _immutable = require('immutable');

var _set = require('../set');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nestedMaps = (0, _immutable.fromJS)({
  a: {
    b: "B"
  },
  f: "F"
});

var childLists = (0, _immutable.fromJS)({
  name: "root",
  children: [{
    name: "child 1",
    children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
  }]
});

(0, _tape2.default)('deepSet', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)(nestedMaps.update((0, _set.deepSet)(['a', 'b'], "new value")), (0, _immutable.fromJS)({
    a: {
      b: "new value"
    },
    f: "F"
  })), 'using no childPath works like setIn');

  test.ok((0, _immutable.is)(childLists.update((0, _set.deepSet)([0, 0], (0, _immutable.fromJS)({ name: "new name" }), ['children'])), (0, _immutable.fromJS)({
    name: "root",
    children: [{
      name: "child 1",
      children: [{ name: "new name" }, { name: "grandchild 2" }]
    }]
  })), 'using childPath works correctly');
});

(0, _tape2.default)('deepSetChildren', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)(nestedMaps.update((0, _set.deepSetChildren)(['f'], (0, _immutable.fromJS)({ x: "X", y: "Y" }))), (0, _immutable.fromJS)({
    a: {
      b: "B"
    },
    f: {
      x: "X",
      y: "Y"
    }
  })), 'using no childPath works like setIn');

  test.ok((0, _immutable.is)(childLists.update((0, _set.deepSetChildren)([0], (0, _immutable.fromJS)([{ name: "aaa" }]), ['children'])), (0, _immutable.fromJS)({
    name: "root",
    children: [{
      name: "child 1",
      children: [{ name: "aaa" }]
    }]
  })), 'using childPath works correctly');
});