'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _immutable = require('immutable');

var _update = require('../update');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nestedMaps = (0, _immutable.fromJS)({
		a: {
				b: "B"
		},
		f: "F"
});

var childLists = (0, _immutable.fromJS)({
		name: "root",
		children: [{
				name: "child 1",
				children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
		}]
});

(0, _tape2.default)('deepUpdate', function (test) {
		test.plan(4);

		test.ok((0, _immutable.is)(nestedMaps.update((0, _update.deepUpdate)(['a'], function (node) {
				return node.set('abc', 123);
		})), (0, _immutable.fromJS)({
				a: {
						b: "B",
						abc: 123
				},
				f: "F"
		})), 'using no childPath works like updateIn');

		test.ok((0, _immutable.is)(nestedMaps.update((0, _update.deepUpdate)(['g'], function (node) {
				return node.set('abc', 123);
		}, null, (0, _immutable.fromJS)({ def: 456 }))), (0, _immutable.fromJS)({
				a: {
						b: "B"
				},
				f: "F",
				g: {
						def: 456,
						abc: 123
				}
		})), 'can use notSetValue with no childPath');

		test.ok((0, _immutable.is)(childLists.update((0, _update.deepUpdate)([0, 1], function (node) {
				return node.set('abc', 123);
		}, ['children'])), (0, _immutable.fromJS)({
				name: "root",
				children: [{
						name: "child 1",
						children: [{ name: "grandchild 1" }, { name: "grandchild 2", abc: 123 }]
				}]
		})), 'using childPath works correctly');

		test.ok((0, _immutable.is)(childLists.update((0, _update.deepUpdate)([0, 2], function (node) {
				return node.set('abc', 123);
		}, ['children'], (0, _immutable.fromJS)({ def: 456 }))), (0, _immutable.fromJS)({
				name: "root",
				children: [{
						name: "child 1",
						children: [{ name: "grandchild 1" }, { name: "grandchild 2" }, { abc: 123, def: 456 }]
				}]
		})), 'can use notSetValue with childPath');
});

(0, _tape2.default)('deepUpdateChildren', function (test) {
		test.plan(3);

		test.ok((0, _immutable.is)(nestedMaps.update((0, _update.deepUpdateChildren)(['a'], function (kids) {
				return kids.set('c', 'C');
		})), (0, _immutable.fromJS)({
				a: {
						b: "B",
						c: "C"
				},
				f: "F"
		})), 'using no childPath works like updateIn');

		test.ok((0, _immutable.is)(nestedMaps.update((0, _update.deepUpdateChildren)(['a', 'b'], function (kids) {
				return kids.set('c', 'C');
		})), nestedMaps), 'deepUpdateChildren with no childPath on a non iterable node means no change is made');

		test.ok((0, _immutable.is)(childLists.update((0, _update.deepUpdateChildren)([0, 0], function (kids) {
				return kids.push((0, _immutable.Map)({ 'abc': 123 }));
		}, ['children'], (0, _immutable.fromJS)([{ def: 456 }]))), (0, _immutable.fromJS)({
				name: "root",
				children: [{
						name: "child 1",
						children: [{
								name: "grandchild 1",
								children: [{ def: 456 }, { abc: 123 }]
						}, { name: "grandchild 2" }]
				}]
		})), 'can update with notSetValue and childPath');
});