'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _immutable = require('immutable');

var _utils = require('../utils');

var _get = require('../get');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nestedMaps = (0, _immutable.fromJS)({
  a: {
    b: "B",
    c: "C",
    d: {
      e: "E"
    }
  },
  f: "F"
});

var nestedLists = (0, _immutable.fromJS)([["A", "B", "C"], ["D", ["E", "F"]], "G"]);

var nodesWithChildCollections = (0, _immutable.fromJS)({
  name: "root",
  children: [{
    name: "child 1",
    children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
  }, {
    name: "child 2",
    children: []
  }, { name: "child 3" }]
});

(0, _tape2.default)('asList', function (test) {
  test.plan(3);

  test.ok((0, _immutable.is)((0, _utils.asList)((0, _immutable.fromJS)(["a", "b"])), (0, _immutable.fromJS)(["a", "b"])), 'passes through Lists with no change');

  test.ok((0, _immutable.is)((0, _utils.asList)(["a", "b"]), (0, _immutable.fromJS)(["a", "b"])), 'converts arrays to Lists');

  test.ok((0, _immutable.is)((0, _utils.asList)(null), (0, _immutable.List)()), 'converts null to an empty List');
});

(0, _tape2.default)('blankNode', function (test) {
  test.plan(3);

  test.ok((0, _immutable.is)((0, _utils.blankNode)(nestedMaps), (0, _immutable.fromJS)((0, _immutable.Map)())), 'turns nested maps blank');

  test.ok((0, _immutable.is)((0, _utils.blankNode)(nestedLists), (0, _immutable.fromJS)((0, _immutable.List)())), 'turns nested lists blank');

  test.ok((0, _immutable.is)((0, _utils.blankNode)(nodesWithChildCollections, ['children']), (0, _immutable.fromJS)({
    children: []
  })), 'converts map nodes with children lists blank');

  // TODO: test with ordered map children
});

(0, _tape2.default)('isLeaf', function (test) {
  test.plan(7);

  test.notOk((0, _utils.isLeaf)(nestedMaps.get('a')), 'is false if node is a map');
  test.ok((0, _utils.isLeaf)(nestedMaps.getIn(['a', 'b'])), 'is true if node is not a map');

  test.notOk((0, _utils.isLeaf)(nestedLists.getIn([1, 1])), 'is false if node is a list');
  test.ok((0, _utils.isLeaf)(nestedLists.get(2)), 'is true if node is not a list');

  var nodeChild1 = (0, _get.deepGet)([0], ['children'])(nodesWithChildCollections);
  var nodeChild2 = (0, _get.deepGet)([1], ['children'])(nodesWithChildCollections);
  var nodeChild3 = (0, _get.deepGet)([2], ['children'])(nodesWithChildCollections);

  test.notOk((0, _utils.isLeaf)(nodeChild1, ['children']), 'is false if node has a child iterable');
  test.ok((0, _utils.isLeaf)(nodeChild3, ['children']), 'is true if node has no child iterable');
  test.ok((0, _utils.isLeaf)(nodeChild2, ['children']), 'is true if node has empty child iterable');
});

(0, _tape2.default)('nodePathToKeys', function (test) {
  test.plan(5);

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeys)([0, 1]), (0, _immutable.fromJS)([0, 1])), 'path is same as keys if childPath is not set');

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeys)([0, 1], []), (0, _immutable.fromJS)([0, 1])), 'path is same as keys if childPath is empty array');

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeys)([0], ['children']), (0, _immutable.fromJS)(['children', 0])), 'path is simply childPath with key appended if only one key');

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeys)([0, 2, 4], ['children']), (0, _immutable.fromJS)(['children', 0, 'children', 2, 'children', 4])), 'path adds childPath before every key in keys');

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeys)([0, 1], ['data', 'children']), (0, _immutable.fromJS)(['data', 'children', 0, 'data', 'children', 1])), 'can cope with childPaths longer than one');
});

(0, _tape2.default)('nodePathToKeysChildren', function (test) {
  test.plan(5);

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeysChildren)([0, 1]), (0, _immutable.fromJS)([0, 1])), 'path is same as keys if childPath is not set');

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeysChildren)([0, 1], []), (0, _immutable.fromJS)([0, 1])), 'path is same as keys if childPath is empty array');

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeysChildren)([], ['children']), (0, _immutable.fromJS)(['children'])), 'path is simply childPath if no keys given');

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeysChildren)([0, 2, 4], ['children']), (0, _immutable.fromJS)(['children', 0, 'children', 2, 'children', 4, 'children'])), 'path adds childPath before every key in keys + 1');

  test.ok((0, _immutable.is)((0, _utils.nodePathToKeysChildren)([0, 1], ['data', 'children']), (0, _immutable.fromJS)(['data', 'children', 0, 'data', 'children', 1, 'data', 'children'])), 'can cope with childPaths longer than one');
});

(0, _tape2.default)('pick', function (test) {
  test.plan(2);

  test.ok((0, _immutable.is)((0, _utils.pick)((0, _immutable.fromJS)({
    a: "A",
    b: "B",
    c: "C",
    d: "D"
  }), ['a', 'c']), (0, _immutable.fromJS)({
    a: "A",
    c: "C"
  })), 'pick only retains designated keys on map');

  test.ok((0, _immutable.is)((0, _utils.pick)((0, _immutable.fromJS)(["A", "B", "C", "D"]), [1, 3]), (0, _immutable.fromJS)(["B", "D"])), 'pick only retains designated keys on list');
});