'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.deepPick = undefined;

var _map = require('./map');

var _utils = require('./utils');

/**
 * @module pick
 */

/**
 * Once fully applied, this returns a new tree containing only nodes lying on the supplied `nodePath`, with all nodes and children outside of the `nodePath` removed.
 *
 * @param {NodePath} nodePath A `NodePath` whose nodes will be filtered and returned.
 * @param {ChildPath} [childPath=null] An `Array` or `List` of keys indicating where to find each node's children from within each node.
 * @return {InputFunction} A partially applied function which accepts a single tree `Iterable`, and returns the modified tree `Iterable`.
 */

function deepPick(nodePath) {
  var childPath = arguments.length <= 1 || arguments[1] === undefined ? null : arguments[1];

  nodePath = (0, _utils.asList)(nodePath);
  childPath = (0, _utils.asList)(childPath);

  return function (tree) {
    return tree.update((0, _map.deepMapOutwards)(function (item, mapNodePath) {
      var childKeys = mapNodePath.size < nodePath.size ? [nodePath.get(mapNodePath.size)] : [];

      return (0, _utils.isLeaf)(item, childPath) ? item : item.updateIn(childPath, function (kids) {
        return (0, _utils.pick)(kids, childKeys);
      });
    }, childPath));
  };
}

exports.deepPick = deepPick;